@@ -2,12 +2,12 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 7.8.4-3-s
+es5id: 7.8.4-19-s
 description: An OctalEscapeSequence is not allowed in a String under Strict Mode
 flags: [onlyStrict]
 ---*/
 
 
 assert.throws(SyntaxError, function() {
-    eval('var x = "a\\4";');
+    eval('var x = "\\463";');
 });
